#!/bin/bash

# Firmware file variable
FIRMWARE_FILE="firmwareupdate.hex"

# Inform the user to disconnect other USB devices
echo "-----------------------------------------------------------------------------------"
echo "Warning: this firmware is only for the Triple with RGB mode led WITHOUT MIDI input."
echo "-----------------------------------------------------------------------------------"
echo "Please ensure that only the Triple controller is connected to a USB port."
read -p "Have you disconnected all other USB devices? (y/n): " disconnected

if [[ "$disconnected" =~ ^[Nn]$ ]]; then
    echo "Operation canceled. Please disconnect other USB devices and try again."
    exit 1
fi

# Check for the availability of avrdude command and offer installation via Homebrew
if ! command -v avrdude &> /dev/null; then
    echo "AVRDUDE is not installed. You can install it using Homebrew:"
    echo "Visit https://brew.sh/ to install Homebrew."
    echo "Then run:"
    echo "brew install avrdude"
    read -p "Do you want to install AVRDUDE now? (y/n): " install_avrdude
    if [[ "$install_avrdude" =~ ^[Yy]$ ]]; then
        brew install avrdude
    else
        echo "Please install AVRDUDE manually before proceeding."
        exit 1
    fi
fi

# Function to find the Arduino port
find_arduino_port() {
    local arduino_port
    arduino_port=$(ls /dev/cu.usbserial* 2>/dev/null | head -n 1)
    echo "$arduino_port"
}

# Check for the availability of the firmware file
if [ ! -f "$FIRMWARE_FILE" ]; then
    echo "The file $FIRMWARE_FILE does not exist. Make sure the firmware file is available."
    exit 1
fi

# Find the Arduino port
DEVICE_NAME=$(find_arduino_port)

if [ -z "$DEVICE_NAME" ]; then
    echo "Triple not detected. Please check the connection and try again. Make sure you use data type USB cable, some cables are only for charging."
    exit 1
fi

# Display port information and ask the user for confirmation (y/n)
echo "Device found on port: $DEVICE_NAME"
read -p "Are you sure you want to flash the firmware on this port? (y/n): " confirmation

if [[ "$confirmation" =~ ^[Yy]$ || "$confirmation" =~ ^[Yy][Ee][Ss]$ ]]; then
    # Execute the AVRDUDE command
    avrdude -v -p atmega328p -c arduino -P "$DEVICE_NAME" -b 57600 -D -U flash:w:"$FIRMWARE_FILE"
    echo "Operation completed."
else
    echo "Operation canceled."
fi
